package betterquesting.client.themes;

import betterquesting.api.storage.BQ_Settings;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api.utils.JsonHelper;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.resources.colors.GuiColorStatic;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import betterquesting.api2.client.gui.resources.lines.IGuiLine;
import betterquesting.api2.client.gui.resources.lines.SimpleLine;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.resources.textures.SlicedTexture;
import betterquesting.api2.client.gui.themes.GuiKey;
import betterquesting.api2.client.gui.themes.IGuiTheme;
import betterquesting.api2.client.gui.themes.IThemeRegistry;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetGUIs;
import betterquesting.api2.client.gui.themes.presets.PresetIcon;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.registry.IFactoryData;
import betterquesting.client.gui2.GuiHome;
import betterquesting.client.gui2.editors.GuiFileBrowser;
import betterquesting.client.gui2.editors.GuiTextEditor;
import betterquesting.client.gui2.editors.nbt.GuiEntitySelection;
import betterquesting.client.gui2.editors.nbt.GuiFluidSelection;
import betterquesting.client.gui2.editors.nbt.GuiItemSelection;
import betterquesting.client.gui2.editors.nbt.GuiNbtEditor;
import betterquesting.core.BetterQuesting;
import betterquesting.handlers.ConfigHandler;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.client.resources.IResource;
import net.minecraft.client.resources.IResourceManager;
import net.minecraft.entity.Entity;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fluids.FluidStack;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_client_themes.jar:betterquesting/client/themes/ThemeRegistry.class */
public class ThemeRegistry implements IThemeRegistry {
    public static final ThemeRegistry INSTANCE = new ThemeRegistry();
    private static final IGuiTexture NULL_TEXTURE = new SlicedTexture(PresetTexture.TX_NULL, new GuiRectangle(0, 0, 32, 32), new GuiPadding(8, 8, 8, 8));
    private static final IGuiLine NULL_LINE = new SimpleLine();
    private static final IGuiColor NULL_COLOR = new GuiColorStatic(-16777216);
    private final HashMap<ResourceLocation, IGuiTexture> defTextures = new HashMap<>();
    private final HashMap<ResourceLocation, IGuiLine> defLines = new HashMap<>();
    private final HashMap<ResourceLocation, IGuiColor> defColors = new HashMap<>();
    private final HashMap<GuiKey<?>, Function<?, GuiScreen>> defGuis = new HashMap<>();
    private final HashMap<ResourceLocation, IGuiTheme> themes = new HashMap<>();
    private final List<ResourceLocation> loadedThemes = new ArrayList();
    private final Gson GSON = new GsonBuilder().setPrettyPrinting().create();
    private IGuiTheme activeTheme = null;
    private boolean setup = false;

    public ThemeRegistry() {
        PresetTexture.registerTextures(this);
        PresetIcon.registerIcons(this);
        PresetLine.registerLines(this);
        PresetColor.registerColors(this);
        setDefaultGui(PresetGUIs.HOME, arg -> {
            return new GuiHome(arg.parent);
        });
        setDefaultGui(PresetGUIs.EDIT_NBT, arg2 -> {
            if (arg2.value instanceof NBTTagCompound) {
                return new GuiNbtEditor(arg2.parent, (NBTTagCompound) arg2.value, arg2.callback);
            }
            if (arg2.value instanceof NBTTagList) {
                return new GuiNbtEditor(arg2.parent, (NBTTagList) arg2.value, arg2.callback);
            }
            return null;
        });
        setDefaultGui(PresetGUIs.EDIT_ITEM, arg3 -> {
            return new GuiItemSelection(arg3.parent, (BigItemStack) arg3.value, arg3.callback);
        });
        setDefaultGui(PresetGUIs.EDIT_FLUID, arg4 -> {
            return new GuiFluidSelection(arg4.parent, (FluidStack) arg4.value, arg4.callback);
        });
        setDefaultGui(PresetGUIs.EDIT_ENTITY, arg5 -> {
            return new GuiEntitySelection(arg5.parent, (Entity) arg5.value, arg5.callback);
        });
        setDefaultGui(PresetGUIs.EDIT_TEXT, arg6 -> {
            return new GuiTextEditor(arg6.parent, (String) arg6.value, arg6.callback);
        });
        setDefaultGui(PresetGUIs.FILE_EXPLORE, arg7 -> {
            return new GuiFileBrowser(arg7.parent, arg7.callback, arg7.root, arg7.filter).allowMultiSelect(arg7.multiSelect);
        });
    }

    public void registerTheme(IGuiTheme theme) {
        if (theme == null || theme.getID() == null) {
            throw new NullPointerException("Cannot register null theme");
        }
        if (this.themes.containsKey(theme.getID())) {
            throw new IllegalArgumentException("Cannot register duplicate theme: " + theme.getID());
        }
        this.themes.put(theme.getID(), theme);
        if (this.activeTheme == null) {
            this.setup = false;
        }
    }

    public void setDefaultTexture(ResourceLocation key, IGuiTexture tex) {
        if (key == null || tex == null) {
            throw new NullPointerException("Tried to register a default theme texture with one or more NULL arguments");
        }
        this.defTextures.put(key, tex);
    }

    public void setDefaultLine(ResourceLocation key, IGuiLine line) {
        if (key == null || line == null) {
            throw new NullPointerException("Tried to register a default theme line with one or more NULL arguments");
        }
        this.defLines.put(key, line);
    }

    public void setDefaultColor(ResourceLocation key, IGuiColor color) {
        if (key == null || color == null) {
            throw new NullPointerException("Tried to register default theme colour with one or more NULL arguments");
        }
        this.defColors.put(key, color);
    }

    public <T> void setDefaultGui(GuiKey<T> key, Function<T, GuiScreen> func) {
        if (key == null || func == null) {
            throw new NullPointerException("Tried to register a default gui with one or more NULL arguments");
        }
        this.defGuis.put(key, func);
    }

    public void setTheme(ResourceLocation id) {
        setTheme(this.themes.get(id), id);
    }

    public IGuiTheme getTheme(ResourceLocation key) {
        if (key == null) {
            return null;
        }
        return this.themes.get(key);
    }

    private void setTheme(IGuiTheme theme, ResourceLocation id) {
        this.activeTheme = theme;
        BQ_Settings.curTheme = id == null ? "" : id.toString();
        if (ConfigHandler.config != null) {
            ConfigHandler.config.get("general", "Theme", "").set(BQ_Settings.curTheme);
            ConfigHandler.config.save();
        } else {
            BetterQuesting.logger.log(Level.WARN, "Unable to save theme setting");
        }
    }

    public IGuiTheme getCurrentTheme() {
        if (!this.setup && this.activeTheme == null) {
            this.activeTheme = getTheme(new ResourceLocation(BQ_Settings.curTheme));
            this.setup = true;
        }
        return this.activeTheme;
    }

    public void loadResourceThemes() {
        List<ResourceLocation> list = this.loadedThemes;
        HashMap<ResourceLocation, IGuiTheme> hashMap = this.themes;
        hashMap.getClass();
        list.forEach((v1) -> {
            r1.remove(v1);
        });
        this.loadedThemes.clear();
        IResourceManager resManager = Minecraft.func_71410_x().func_110442_L();
        loop0: for (String domain : resManager.func_135055_a()) {
            ResourceLocation res = new ResourceLocation(domain, "bq_themes.json");
            try {
                List<IResource> list2 = resManager.func_135056_b(res);
                for (IResource iresource : list2) {
                    try {
                        InputStreamReader isr = new InputStreamReader(iresource.func_110527_b(), StandardCharsets.UTF_8);
                        Throwable th = null;
                        try {
                            try {
                                JsonArray jAry = (JsonArray) this.GSON.fromJson(isr, JsonArray.class);
                                isr.close();
                                for (int i = 0; i < jAry.size(); i++) {
                                    JsonElement je = jAry.get(i);
                                    if (!(je instanceof JsonObject)) {
                                        BetterQuesting.logger.log(Level.WARN, "Invalid theme entry at index " + i + " in " + domain);
                                    } else {
                                        JsonObject jThm = je.getAsJsonObject();
                                        if (jThm.has("themeType")) {
                                            BetterQuesting.logger.warn("Deprecated legacy theme entry " + i + " in " + domain);
                                            BetterQuesting.logger.warn("Please convert this to the new format");
                                            loadLegacy(jThm, domain);
                                        } else {
                                            ResourceLocation parentID = !jThm.has("themeParent") ? null : new ResourceLocation(JsonHelper.GetString(jThm, "themeParent", "minecraft:null"));
                                            String themeName = JsonHelper.GetString(jThm, "themeName", "Unnamed Theme");
                                            String idRaw = JsonHelper.GetString(jThm, "themeID", themeName).toLowerCase().trim().replaceAll(" ", "_");
                                            if (!idRaw.contains(":")) {
                                                idRaw = domain + ":" + idRaw;
                                            }
                                            ResourceLocation themeId = new ResourceLocation(idRaw);
                                            int n = 0;
                                            while (this.themes.containsKey(themeId)) {
                                                int i2 = n;
                                                n++;
                                                themeId = new ResourceLocation(domain, idRaw + i2);
                                            }
                                            try {
                                                ResourceTheme resTheme = new ResourceTheme(parentID, themeId, themeName);
                                                JsonObject jsonTextureRoot = JsonHelper.GetObject(jThm, "textures");
                                                for (Map.Entry<String, JsonElement> entry : jsonTextureRoot.entrySet()) {
                                                    if (entry.getValue().isJsonObject()) {
                                                        JsonObject joTex = entry.getValue().getAsJsonObject();
                                                        ResourceLocation typeID = new ResourceLocation(JsonHelper.GetString(joTex, "textureType", ""));
                                                        IFactoryData<IGuiTexture, JsonObject> tFact = ResourceRegistry.INSTANCE.getTexReg().getFactory(typeID);
                                                        if (tFact == null) {
                                                            BetterQuesting.logger.error("Unknown texture type " + typeID + " for theme " + themeName + " in " + domain);
                                                        } else {
                                                            IGuiTexture gTex = (IGuiTexture) tFact.loadFromData(joTex);
                                                            if (gTex == null) {
                                                                BetterQuesting.logger.error("Failed to load texture type " + typeID + " for theme " + themeName + " in " + domain);
                                                            } else {
                                                                resTheme.setTexture(new ResourceLocation(entry.getKey()), gTex);
                                                            }
                                                        }
                                                    }
                                                }
                                                JsonObject jsonColourRoot = JsonHelper.GetObject(jThm, "colors");
                                                for (Map.Entry<String, JsonElement> entry2 : jsonColourRoot.entrySet()) {
                                                    if (entry2.getValue() instanceof JsonObject) {
                                                        JsonObject joCol = entry2.getValue().getAsJsonObject();
                                                        ResourceLocation typeID2 = new ResourceLocation(JsonHelper.GetString(joCol, "colorType", ""));
                                                        IFactoryData<IGuiColor, JsonObject> cFact = ResourceRegistry.INSTANCE.getColorReg().getFactory(typeID2);
                                                        if (cFact == null) {
                                                            BetterQuesting.logger.error("Unknown color type " + typeID2 + " for theme " + themeName + " in " + domain);
                                                        } else {
                                                            IGuiColor gCol = (IGuiColor) cFact.loadFromData(joCol);
                                                            if (gCol == null) {
                                                                BetterQuesting.logger.error("Failed to load color type " + typeID2 + " for theme " + themeName + " in " + domain);
                                                            } else {
                                                                resTheme.setColor(new ResourceLocation(entry2.getKey()), gCol);
                                                            }
                                                        }
                                                    }
                                                }
                                                JsonObject jsonLinesRoot = JsonHelper.GetObject(jThm, "lines");
                                                for (Map.Entry<String, JsonElement> entry3 : jsonLinesRoot.entrySet()) {
                                                    if (entry3.getValue() instanceof JsonObject) {
                                                        JsonObject joLine = entry3.getValue().getAsJsonObject();
                                                        ResourceLocation typeID3 = new ResourceLocation(JsonHelper.GetString(joLine, "lineType", ""));
                                                        IFactoryData<IGuiLine, JsonObject> lFact = ResourceRegistry.INSTANCE.getLineReg().getFactory(typeID3);
                                                        if (lFact == null) {
                                                            BetterQuesting.logger.error("Unknown line type " + typeID3 + " for theme " + themeName + " in " + domain);
                                                        } else {
                                                            IGuiLine gLine = (IGuiLine) lFact.loadFromData(joLine);
                                                            if (gLine == null) {
                                                                BetterQuesting.logger.error("Failed to load line type " + typeID3 + " for theme " + themeName + " in " + domain);
                                                            } else {
                                                                resTheme.setLine(new ResourceLocation(entry3.getKey()), gLine);
                                                            }
                                                        }
                                                    }
                                                }
                                                this.themes.put(resTheme.getID(), resTheme);
                                                this.loadedThemes.add(resTheme.getID());
                                            } catch (Exception e) {
                                                BetterQuesting.logger.error("Failed to load theme entry " + i + " in " + domain, e);
                                            }
                                        }
                                    }
                                }
                                if (isr != null) {
                                    if (0 != 0) {
                                        try {
                                            isr.close();
                                        } catch (Throwable th2) {
                                            th.addSuppressed(th2);
                                        }
                                    } else {
                                        isr.close();
                                    }
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                throw th3;
                                break loop0;
                            }
                        } finally {
                        }
                    } catch (Exception e2) {
                        BetterQuesting.logger.error("Error reading bq_themes.json from " + domain, e2);
                    }
                }
            } catch (Exception e3) {
            }
        }
    }

    @Deprecated
    private void loadLegacy(JsonObject json, String domain) {
        IGuiTheme theme = LegacyThemeLoader.INSTANCE.loadTheme(json, domain);
        if (theme == null) {
            BetterQuesting.logger.error("Failed to load legacy theme from " + domain);
            return;
        }
        if (this.themes.containsKey(theme.getID())) {
            BetterQuesting.logger.error("Unable to register legacy resource theme with duplicate ID: " + theme.getID());
        }
        this.themes.put(theme.getID(), theme);
        this.loadedThemes.add(theme.getID());
    }

    public IGuiTexture getTexture(ResourceLocation key) {
        if (key == null) {
            return NULL_TEXTURE;
        }
        IGuiTexture tex = null;
        if (getCurrentTheme() != null) {
            tex = this.activeTheme.getTexture(key);
        }
        if (tex == null) {
            tex = this.defTextures.get(key);
        }
        return tex == null ? NULL_TEXTURE : tex;
    }

    public IGuiLine getLine(ResourceLocation key) {
        if (key == null) {
            return NULL_LINE;
        }
        IGuiLine line = null;
        if (getCurrentTheme() != null) {
            line = this.activeTheme.getLine(key);
        }
        if (line == null) {
            line = this.defLines.get(key);
        }
        return line == null ? NULL_LINE : line;
    }

    public IGuiColor getColor(ResourceLocation key) {
        if (key == null) {
            return NULL_COLOR;
        }
        IGuiColor color = null;
        if (getCurrentTheme() != null) {
            color = this.activeTheme.getColor(key);
        }
        if (color == null) {
            color = this.defColors.get(key);
        }
        return color == null ? NULL_COLOR : color;
    }

    public <T> GuiScreen getGui(GuiKey<T> key, T args) {
        if (key == null) {
            return null;
        }
        Function<?, GuiScreen> function = null;
        if (getCurrentTheme() != null) {
            function = this.activeTheme.getGui(key);
        }
        if (function == null) {
            function = this.defGuis.get(key);
        }
        if (function == null) {
            return null;
        }
        return function.apply(args);
    }

    public List<IGuiTheme> getAllThemes() {
        return new ArrayList(this.themes.values());
    }

    public ResourceLocation[] getKnownTextures() {
        return (ResourceLocation[]) this.defTextures.keySet().toArray(new ResourceLocation[0]);
    }

    public ResourceLocation[] getKnownColors() {
        return (ResourceLocation[]) this.defColors.keySet().toArray(new ResourceLocation[0]);
    }

    public ResourceLocation[] getKnownLines() {
        return (ResourceLocation[]) this.defLines.keySet().toArray(new ResourceLocation[0]);
    }

    public GuiKey[] getKnownGuis() {
        return (GuiKey[]) this.defGuis.keySet().toArray(new GuiKey[0]);
    }
}
